@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.1003';
+our $VERSION = '0.1100';
 
 use Moo;
 use strictures 2;
@@ -143,14 +143,19 @@ has notes => (
 );
 
 
+has net => (
+    is       => 'ro',
+    init_arg => undef,
+    default  => sub { {} },
+);
+
+
 sub process {
     my ($self) = @_;
 
     my $analysis;
 
-    my $files = ref $self->in_file eq 'ARRAY' ? $self->in_file : [ $self->in_file ];
-
-    for my $file ( @$files ) {
+    for my $file ( @{ $self->in_file } ) {
         # Counter for the tracks seen
         my $i = 0;
 
@@ -183,11 +188,22 @@ sub process {
             # Declare the notes to inspect
             my $text = '';
 
+            my @group;
+            my $last;
+
             # Accumulate the notes
             for my $event ( @events ) {
                 # Transliterate MIDI note numbers to alpha-code
                 ( my $str = $event->[3] ) =~ tr/0-9/a-j/;
                 $text .= "$str ";
+
+                if (@group == $self->ngram_size) {
+                    my $group = join ' ', @group;
+                    $self->net->{ $last . '-' . $group }++ if $last;
+                    $last = $group;
+                    shift @group;
+                }
+                push @group, $event->[3];
             }
 
             # Parse the note text into ngrams
@@ -416,7 +432,7 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.1003
+version 0.1100
 
 =head1 SYNOPSIS
 
@@ -432,6 +448,8 @@ version 0.1003
 
   my $analysis = $mng->process;
 
+  print Dumper $mng->net;
+
   my $playback = $mng->populate;
 
   $mng->write;
@@ -439,8 +457,8 @@ version 0.1003
 =head1 DESCRIPTION
 
 C<MIDI::Ngram> parses a given list of MIDI files, finds the top
-repeated note phrases, outputs the analysis, and renders them to a
-MIDI file if desired.
+repeated note phrases, outputs the analysis, transition network, and
+renders them to a MIDI file if desired.
 
 =head1 ATTRIBUTES
 
@@ -546,7 +564,13 @@ runtime.
 
 =head2 notes
 
-The hash-reference bucket of ngrams.  Constructed at runtime.
+The hash-reference bucket of ngrams.  Constructed by the B<process>
+method.
+
+=head2 net
+
+A hash-reference ngram transition network.  Constructed by the
+B<process> method.
 
 =head1 METHODS
 
@@ -558,13 +582,13 @@ Create a new C<MIDI::Ngram> object.
 
 =head2 process
 
-  my $analysis = $mng->process;
+  $analysis = $mng->process;
 
 Find all ngram phrases and return the note analysis.
 
 =head2 populate
 
-  my $playback = $mng->populate;
+  $playback = $mng->populate;
 
 Add notes to the MIDI score and return the playback notes.
 
